@@ -32,7 +32,7 @@ importance <- function(x, ...)  UseMethod("importance")
 # @aliases importance
 # @export 
 importance.blockForest <- function(x, ...) {
-  if (class(x) != "blockForest") {
+  if (!inherits(x, "blockForest")) {
     stop("Object ist no blockForest object.")
   }
   if (is.null(x$variable.importance) || length(x$variable.importance) < 1) {
@@ -89,7 +89,7 @@ importance.blockForest <- function(x, ...) {
 # @export 
 importance_pvalues <- function(x, method = c("janitza", "altmann"), num.permutations = 100, formula = NULL, data = NULL, ...) {
   method <- match.arg(method)
-  if (class(x) != "blockForest" & class(x) != "holdoutRF") {
+  if (!inherits(x, c("blockForest", "holdoutRF"))) {
     stop("Object is no blockForest or holdoutRF object.")
   }
   if (x$importance.mode == "none" || is.null(x$variable.importance) || length(x$variable.importance) < 1) {
@@ -100,7 +100,7 @@ importance_pvalues <- function(x, method = c("janitza", "altmann"), num.permutat
     if (x$importance.mode == "impurity") {
       stop("Impurity variable importance found. Please use (hold-out) permutation importance or corrected impurity importance to use this method.")
     }
-    if (class(x) != "holdoutRF" && x$importance.mode == "permutation") {
+    if (!inherits(x, "holdoutRF") && x$importance.mode == "permutation") {
       warning("Permutation variable importance found, inaccurate p-values. Please use hold-out permutation importance or corrected impurity importance to use this method.")
     }
     if (x$treetype != "Classification") {
@@ -124,7 +124,7 @@ importance_pvalues <- function(x, method = c("janitza", "altmann"), num.permutat
       warning("Only few negative importance values found, inaccurate p-values. Consider the 'altmann' approach.")
     }
   } else if (method == "altmann") {
-    if (class(x) != "blockForest") {
+    if (!is(x, "blockForest")) {
       stop("Altmann method not available for holdoutRF objects.")
     }
     if (is.null(formula) || is.null(data)) {
